@@ -25,7 +25,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'CFLAGS': '-fno-strict-aliasing -O2 -pipe -DNDEBUG -O2 -pipe   -fPIC',
  'CFLAGSFORSHARED': '-fPIC',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-shared' '--srcdir=/usr/pobj/Python-2.7.10/Python-2.7.10' '--with-fpectl' '--with-threads' '--enable-ipv6' '--with-cxx_main' '--with-system-expat' '--with-system-ffi' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' 'CPPFLAGS=-I/usr/local/include'",
+ 'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-shared' '--srcdir=/usr/obj/ports/Python-2.7.11/Python-2.7.11' '--with-fpectl' '--with-threads' '--enable-ipv6' '--with-cxx_main' '--with-system-expat' '--with-system-ffi' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib/' 'CPPFLAGS=-I/usr/local/include'",
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python2.7',
  'COREPYTHONPATH': ':plat-openbsd5:lib-tk:lib-old',
@@ -87,6 +87,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_CHOWN': 1,
  'HAVE_CHROOT': 1,
  'HAVE_CLOCK': 1,
+ 'HAVE_COMPUTED_GOTOS': 1,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
  'HAVE_COPYSIGN': 1,
@@ -135,7 +136,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_FTRUNCATE': 1,
  'HAVE_GAI_STRERROR': 1,
  'HAVE_GAMMA': 1,
- 'HAVE_GCC_ASM_FOR_X87': 0,
+ 'HAVE_GCC_ASM_FOR_X87': 1,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETCWD': 1,
  'HAVE_GETC_UNLOCKED': 1,
@@ -353,16 +354,16 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HGBRANCH': '',
  'HGTAG': '',
  'HGVERSION': '',
- 'HOST_GNU_TYPE': 'sh-unknown-openbsd5.8',
+ 'HOST_GNU_TYPE': 'i386-unknown-openbsd5.9',
  'HURD_C_THREADS': 0,
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include /usr/local/include/python2.7 /usr/local/include/python2.7',
  'INCLUDEDIR': '/usr/local/include',
  'INCLUDEPY': '/usr/local/include/python2.7',
- 'INSTALL': '/usr/pobj/Python-2.7.10/bin/install -c',
- 'INSTALL_DATA': '/usr/pobj/Python-2.7.10/bin/install -c  -m 644',
- 'INSTALL_PROGRAM': '/usr/pobj/Python-2.7.10/bin/install -c -s  -m 755',
- 'INSTALL_SCRIPT': '/usr/pobj/Python-2.7.10/bin/install -c  -m 755',
- 'INSTALL_SHARED': '/usr/pobj/Python-2.7.10/bin/install -c -m 555',
+ 'INSTALL': '/usr/obj/ports/Python-2.7.11/bin/install -c',
+ 'INSTALL_DATA': '/usr/obj/ports/Python-2.7.11/bin/install -c  -m 644',
+ 'INSTALL_PROGRAM': '/usr/obj/ports/Python-2.7.11/bin/install -c -s  -m 755',
+ 'INSTALL_SCRIPT': '/usr/obj/ports/Python-2.7.11/bin/install -c  -m 755',
+ 'INSTALL_SHARED': '/usr/obj/ports/Python-2.7.11/bin/install -c -m 555',
  'INSTSONAME': 'libpython2.7.so.0.0',
  'LDCXXSHARED': 'c++ -pthread -shared -fPIC',
  'LDFLAGS': '-L/usr/local/lib/',
@@ -386,6 +387,9 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'LIBSUBDIRS': 'lib-tk lib-tk/test lib-tk/test/test_tkinter \\',
  'LINKCC': 'c++ -pthread',
  'LINKFORSHARED': '-Wl,--export-dynamic',
+ 'LLVM_PROF_ERR': 'no',
+ 'LLVM_PROF_FILE': '',
+ 'LLVM_PROF_MERGER': '',
  'LN': 'ln',
  'LOCALMODLIBS': '',
  'MACHDEP': 'openbsd5',
@@ -409,6 +413,9 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'MVWDELCH_IS_EXPRESSION': 1,
  'OBJECT_OBJS': '\\',
  'OLDPATH': ':lib-old',
+ 'OPCODETARGETGEN': '\\',
+ 'OPCODETARGETGEN_FILES': '\\',
+ 'OPCODETARGETS_H': '\\',
  'OPT': '-DNDEBUG -O2 -pipe   -fPIC',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -423,13 +430,15 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PGENOBJS': '\\ \\',
  'PGENSRCS': '\\ \\',
  'PGOBJS': '\\',
+ 'PGO_PROF_GEN_FLAG': '',
+ 'PGO_PROF_USE_FLAG': '',
  'PGSRCS': '\\',
  'PLATDIR': 'plat-openbsd5',
  'PLATMACDIRS': 'plat-mac plat-mac/Carbon plat-mac/lib-scriptpackages \\',
  'PLATMACPATH': ':plat-mac:plat-mac/lib-scriptpackages',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': './Tools/pybench/pybench.py -n 2 --with-gc --with-syscheck',
+ 'PROFILE_TASK': '-m test.regrtest --pgo',
  'PSRCS': '\\',
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -455,7 +464,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'RANLIB': 'ranlib',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/pobj/Python-2.7.10/Python-2.7.10',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.11/Python-2.7.11',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '',
@@ -470,7 +479,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
  'SIZEOF_LONG': 4,
- 'SIZEOF_LONG_DOUBLE': 8,
+ 'SIZEOF_LONG_DOUBLE': 12,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
@@ -493,13 +502,13 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SVNVERSION': 'echo Unversioned directory',
  'SYSLIBS': '-lm',
  'SYS_SELECT_WITH_SYS_TIME': 1,
- 'TANH_PRESERVES_ZERO_SIGN': 1,
+ 'TANH_PRESERVES_ZERO_SIGN': 0,
  'TCLTK_INCLUDES': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '-l',
  'TESTPATH': '',
  'TESTPROG': './Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/pobj/Python-2.7.10/Python-2.7.10 ./python -Wd -3 -E -tt',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-2.7.11/Python-2.7.11 ./python -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
  'TIME_WITH_SYS_TIME': 1,
@@ -507,6 +516,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'TM_IN_SYS_TIME': 0,
  'UNICODE_OBJS': 'Objects/unicodeobject.o Objects/unicodectype.o',
  'UNIVERSALSDK': '',
+ 'USE_COMPUTED_GOTOS': 0,
  'USE_TOOLBOX_OBJECT_GLUE': 0,
  'VA_LIST_IS_ARRAY': 0,
  'VERSION': '2.7',
@@ -521,13 +531,13 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_THREAD': 1,
  'WITH_TSC': 0,
  'WITH_VALGRIND': 0,
- 'X87_DOUBLE_ROUNDING': 0,
+ 'X87_DOUBLE_ROUNDING': 1,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/pobj/Python-2.7.10/Python-2.7.10',
- 'abs_srcdir': '/usr/pobj/Python-2.7.10/Python-2.7.10',
- 'build': 'sh-unknown-openbsd5.8',
+ 'abs_builddir': '/usr/obj/ports/Python-2.7.11/Python-2.7.11',
+ 'abs_srcdir': '/usr/obj/ports/Python-2.7.11/Python-2.7.11',
+ 'build': 'i386-unknown-openbsd5.9',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
- 'host': 'sh-unknown-openbsd5.8',
+ 'host': 'i386-unknown-openbsd5.9',
  'prefix': '/usr/local',
  'srcdir': '.'}
